@@ -2,8 +2,8 @@
 #
 # This owes a lot to littler.R  in the littler sources
 
-ExcludeVars <- c("R_SESSION_TMPDIR", "R_HISTFILE", "R_LIBRARY_DIR",
-                 "R_LIBS", "R_PACKAGE_DIR")
+ExcludeVars <- c("R_SESSION_TMPDIR", "R_HISTFILE", "R_LIBRARY_DIR", "R_LIBS",
+                 "R_PACKAGE_DIR", "R_SESSION_INITIALIZED")
 IncludeVars <- Sys.getenv()
 IncludeVars <- IncludeVars[grep("^R_",names(IncludeVars),perl=TRUE)]
 if (.Platform$OS.type == "windows") {
@@ -12,8 +12,8 @@ if (.Platform$OS.type == "windows") {
 }
 cat("    const char *R_VARS[] = {\n")
 for (i in 1:length(IncludeVars)){
-	if (names(IncludeVars)[i] %in% ExcludeVars)
-		next
-	cat('        "',names(IncludeVars)[i],'","',IncludeVars[i],'",\n',sep='')
+    if (names(IncludeVars)[i] %in% ExcludeVars)
+        next
+    cat('        "',names(IncludeVars)[i],'","',IncludeVars[i],'",\n',sep='')
 }
 cat("        NULL\n    };\n")
